@@ -1,17 +1,6 @@
-"""LaminDB manager.
+"""LaminDB setup.
 
-The Python API here has a 1:1 correspondnce to the CLI tool `lndb`.
-
-Import the package::
-
-   import lndb
-
-Settings:
-
-.. autosummary::
-   :toctree:
-
-   settings
+Every function in the API below matches a command in the `lamin` CLI.
 
 Setup user account:
 
@@ -46,6 +35,12 @@ Manage creating and testing migrations (deployment is automatic):
 
    migrate
 
+Settings:
+
+.. autosummary::
+   :toctree:
+
+   settings
 
 Developer API.
 
@@ -55,7 +50,7 @@ Developer API.
    dev
 """
 
-__version__ = "0.35.3"  # denote a release candidate for 0.1.0 with 0.1rc1
+__version__ = "0.37.0"  # denote a release candidate for 0.1.0 with 0.1rc1
 
 import sys
 from os import name as _os_name
