@@ -1,36 +1,14 @@
-import os
-import shutil
 from pathlib import Path
 
 import nox
+from laminci import __version__, upload_docs_dir
+
+if __version__ < "0.2.4":
+    raise RuntimeError("Upgrade laminci version.")
 
 nox.options.reuse_existing_virtualenvs = True
 
 
-def upload_docs_dir():
-    import lndb
-
-    if os.environ["GITHUB_EVENT_NAME"] != "push":
-        return
-    package_name = "lndb"
-    filestem = f"{package_name}_docs"
-    filename = shutil.make_archive(filestem, "zip", "./docs")
-    lndb.load("testuser1/lamin-site-assets", migrate=True)
-
-    import lamindb as ln
-    import lamindb.schema as lns
-
-    with ln.Session() as ss:
-        dobject = ss.select(ln.DObject, name=filestem).one_or_none()
-        pipeline = ln.add(lns.Pipeline, name=f"CI {package_name}")
-        run = lns.Run(pipeline=pipeline)
-        if dobject is None:
-            dobject = ln.DObject(filename, source=run)
-        else:
-            dobject.source = run
-        ss.add(dobject)
-
-
 @nox.session
 def lint(session: nox.Session) -> None:
     session.install("pre-commit")
